@@ -15,19 +15,20 @@ class LoadImageXNATd(MapTransform):
     MapTransform for importing image data from XNAT
     """
 
-    def __init__(self, keys: KeysCollection, actions=None, xnat_configuration=None, image_loader=LoadImage, expected_filetype='.dcm'):
+    def __init__(self, keys: KeysCollection, actions=None, xnat_configuration=None, image_loader=LoadImage, validate_data:bool = False, expected_filetype='.dcm'):
         super().__init__(keys)
         self.image_loader = image_loader
         self.xnat_configuration = xnat_configuration
         self.actions = actions
         self.expected_filetype = expected_filetype
+        self.validate_data = validate_data
 
     def __call__(self, data):
         d = dict(data)
         for key in self.keys:
             if key in data:
 
-                for action in self.actions:
+                for action, data_label in self.actions:
                     """loops over actions in action list, if no action is triggered then raise a warning actions are 
                     functions that return any of projects, subjects, experiments, scans, or resources XNAT object 
                     along with a key to be used in the data dictionary"""
@@ -36,12 +37,24 @@ class LoadImageXNATd(MapTransform):
 
                     with xnat.connect(server=self.xnat_configuration['server'],
                                       user=self.xnat_configuration['user'],
-                                      password=self.xnat_configuration['password'], verify=bool(os.getenv('MLOPS_SSL'))) as session:
+                                      password=self.xnat_configuration['password'],
+                                      verify=bool(os.getenv('MLOPS_SSL'))) as session:
 
                         "connect session to subject uri"
                         subject_obj = session.create_object(d['subject_uri'])
                         "perform action on subject object"
-                        xnat_obj, image_label = action(subject_obj)
+                        try:
+                            xnat_obj = action(subject_obj)
+                        except TypeError:
+                            logger.warn(f'No suitable data found for action {action} and subject {d["subject_uri"]}')
+                            d[data_label] = None
+
+                        if self.validate_data:
+                            if xnat_obj:
+                                d[data_label] = True
+                            else:
+                                d[data_label] = False
+                            return d
 
                         with tempfile.TemporaryDirectory() as tmpdirname:
                             "download image from XNAT"
@@ -60,7 +73,7 @@ class LoadImageXNATd(MapTransform):
 
                             image, meta = self.image_loader()(image_dirs[0])
 
-                            d[image_label] = image
-                            d[image_label + '_meta'] = meta
+                            d[data_label] = image
+                            d[data_label + '_meta'] = meta
 
             return d
